==> apimgmt-app-1.1.0-20251024.055834-1-sources.jar: com/digiwin/athena/apimgmt/service/util/DevelopmentPlatformServiceUtil.java <==
package com.digiwin.athena.apimgmt.service.util;

import com.alibaba.fastjson.JSONObject;
import com.digiwin.athena.apimgmt.constants.ApimgmtConstant;
import com.digiwin.athena.apimgmt.model.StandardApiVersion;
import com.digiwin.athena.apimgmt.services.ApiMgmtDevelopmentPlatformService;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 开发平台处理类util
 */
@Service
public class DevelopmentPlatformServiceUtil extends GenericServiceUtil<ApiMgmtDevelopmentPlatformService> {

    private static final Logger log = LoggerFactory.getLogger(DevelopmentPlatformServiceUtil.class);
    private static ApiMgmtDevelopmentPlatformService service;

    @Override
    @Autowired
    public void setService(ApiMgmtDevelopmentPlatformService pService) {
        service = pService;
    }

    public static void sendApiToDevelopmentPlatform(StandardApiVersion tStandardApiVersion) throws Exception {
        //非esp的API不需要同步
        if (StringUtils.isNoneBlank(tStandardApiVersion.getStandardApi().getApiType()) && !ApimgmtConstant.DEFAULT_API_TYPE.equals(tStandardApiVersion.getStandardApi().getApiType())) {
            log.info("非esp的API不需要同步,apiName={}", tStandardApiVersion.getStandardApi().getName());
            return;
        }
        service.sendApiToDevelopmentPlatform(tStandardApiVersion);
    }

    public static List<String> getWithAuthList(String pUserToken, String type) throws Exception {
        JSONObject jsonObject = service.getWithAuthList(pUserToken, type);
        JSONObject data = jsonObject.getJSONObject("data");
        if (null != data) {
            Object obj = data.get("obj");
            if (null != obj) {
                return (List<String>) obj;
            }
        }
        return new ArrayList<>();
    }

}

==> apimgmt-app-1.1.0-20251031.062104-30-sources.jar: com/digiwin/athena/apimgmt/service/util/DevelopmentPlatformServiceUtil.java <==
package com.digiwin.athena.apimgmt.service.util;

import cn.hutool.core.util.StrUtil;
import cn.hutool.extra.spring.SpringUtil;
import com.alibaba.fastjson.JSONObject;
import com.digiwin.athena.apimgmt.ApiMgmtApplicationParameter;
import com.digiwin.athena.apimgmt.constants.ApimgmtConstant;
import com.digiwin.athena.apimgmt.event.ApiReviewedEvent;
import com.digiwin.athena.apimgmt.model.StandardApiVersion;
import com.digiwin.athena.apimgmt.services.ApiMgmtDevelopmentPlatformService;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 开发平台处理类util
 */
@Service
public class DevelopmentPlatformServiceUtil extends GenericServiceUtil<ApiMgmtDevelopmentPlatformService> {

    private static final Logger log = LoggerFactory.getLogger(DevelopmentPlatformServiceUtil.class);
    private static ApiMgmtDevelopmentPlatformService service;

    public static void sendApiToDevelopmentPlatform(StandardApiVersion tStandardApiVersion) throws Exception {
        try {
            String msg = service.sendDpMessage(tStandardApiVersion);
            SpringUtil.publishEvent(new ApiReviewedEvent(msg));
        } catch (Exception e) {
            log.info("api更新处理事件异常！", e);
            throw new Exception("api更新处理事件异常");
        }

        if (StrUtil.isNotEmpty(ApiMgmtApplicationParameter._DEV_PLATE_URL)) {
            //非esp的API不需要同步
            if (StringUtils.isNoneBlank(tStandardApiVersion.getStandardApi().getApiType())
                    && !ApimgmtConstant.DEFAULT_API_TYPE.equals(tStandardApiVersion.getStandardApi().getApiType())) {
                log.info("非esp的API不需要同步,apiName={}", tStandardApiVersion.getStandardApi().getName());
                return;
            }
            service.sendApiToDevelopmentPlatform(tStandardApiVersion);
        }
    }

    @Override
    @Autowired
    public void setService(ApiMgmtDevelopmentPlatformService pService) {
        service = pService;
    }

    public static List<String> getWithAuthList(String pUserToken, String type) throws Exception {
        JSONObject jsonObject = service.getWithAuthList(pUserToken, type);
        JSONObject data = jsonObject.getJSONObject("data");
        if (null != data) {
            Object obj = data.get("obj");
            if (null != obj) {
                return (List<String>) obj;
            }
        }
        return new ArrayList<>();
    }

}
